@@ -24,8 +24,9 @@ from __future__ import annotations
 
 import math
 from abc import ABC, ABCMeta
+from collections.abc import Collection
 from pprint import pformat
-from typing import TYPE_CHECKING, Any, Collection
+from typing import TYPE_CHECKING, Any
 from uuid import uuid4
 
 from abilian.app import db
